@@ -4,17 +4,30 @@ from __future__ import unicode_literals
 
 __all__ = ["ApplicationError", "TagError"]
 
+from typing import Optional
+
+from java.lang import Exception as JavaException
+from java.lang import Throwable
+
+from incendium.types import String
+
 
 class ApplicationError(Exception):
     """Application Error class."""
 
-    def __init__(self, message, inner_exception=None, cause=None):
+    def __init__(
+        self,
+        message,  # type: String
+        inner_exception=None,  # type: Optional[JavaException]
+        cause=None,  # type: Optional[Throwable]
+    ):
+        # type: (...) -> None
         """Application Error initializer.
 
         Args:
-            message (str): The error message.
-            inner_exception (object): The inner Exception. Optional.
-            cause (object): The cause of the Exception. Optional.
+            message: The error message.
+            inner_exception: The inner Exception. Optional.
+            cause: The cause of the Exception. Optional.
         """
         self.message = message
         self.inner_exception = inner_exception
@@ -39,10 +52,11 @@ class TagError(Exception):
     """Tag Error class."""
 
     def __init__(self, message):
+        # type: (String) -> None
         """Tag Error initializer.
 
         Args:
-            message (str): The error message.
+            message: The error message.
         """
         self.message = message
         super(TagError, self).__init__(message)
